@@ -34,6 +34,7 @@
 #include "gth-file-view-list.h"
 #include "gthumb-marshal.h"
 #include "gthumb-enum-types.h"
+#include "file-utils.h"
 #include "file-data.h"
 #include "icons/pixbufs.h"
 #include "pixbuf-utils.h"
@@ -1578,7 +1579,7 @@ comp_func_path (gconstpointer  ptr1,
 	if ((fd1 == NULL) || (fd2 == NULL))
 		return 0;
 
-	return strcmp (fd1->path, fd2->path);
+	return uricmp (fd1->path, fd2->path);
 }
 
 
