@@ -152,8 +152,8 @@ static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
-	GthBrowser *browser = data->browser;
-	gboolean    thread_done;
+	GtkWidget *browser = (GtkWidget*) data->browser;
+	gboolean   thread_done;
 
 	/* Remove check. */
 
@@ -180,8 +180,17 @@ destroy_cb (GtkWidget  *widget,
 
 	/**/
 
-	if (data->view_folder)
-		gth_browser_go_to_directory (data->browser, data->local_folder);
+	if (data->view_folder) {
+		if (browser == NULL) {
+			browser = gth_browser_get_current_browser ();
+			if (browser != NULL)
+				gth_browser_go_to_directory (GTH_BROWSER (browser), data->local_folder);
+			else
+				browser = gth_browser_new (data->local_folder);
+			gtk_window_present (GTK_WINDOW (browser));
+		} else
+			gth_browser_go_to_directory (data->browser, data->local_folder);
+	}
 
 	/**/
 
@@ -208,7 +217,10 @@ destroy_cb (GtkWidget  *widget,
 
 	if (ImportPhotos) {
 		ImportPhotos = FALSE;
-		gth_window_close (GTH_WINDOW (browser));
+		if (browser != NULL)
+			gth_window_close (GTH_WINDOW (browser));
+		else
+			gtk_main_quit ();
 	}
 }
 
@@ -1063,7 +1075,7 @@ get_folder_name (DialogData *data)
 	char *film_name;
 	char *path;
 
-	esc_destination = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data->destination_filechooserbutton));
+	esc_destination = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->destination_filechooserbutton));
 	destination = gnome_vfs_unescape_string (esc_destination, "");
 	g_free (esc_destination);
 
@@ -1137,7 +1149,7 @@ get_file_name (DialogData *data,
 
 	if (data->keep_original_filename) {
 		file_name = g_strdup (file_name_from_path (camera_path));
-		set_lowercase (file_name);
+		/* set_lowercase (file_name); see #339291 */
 
 	} else {
 		char *s, *new_ext;
@@ -1199,8 +1211,8 @@ save_image (DialogData *data,
 {
 	CameraFile *file;
 	char       *camera_folder;
-	const char *camera_filename;
-	char       *local_path;
+	const char *camera_filename, *local_path;
+	char       *file_uri;
 
 	gp_file_new (&file);
 
@@ -1213,9 +1225,11 @@ save_image (DialogData *data,
 			    file, 
 			    data->context);
 
-	local_path = get_file_name (data, camera_path, local_folder, n);
+	file_uri = get_file_name (data, camera_path, local_folder, n);
 
-	if (gp_file_save (file, local_path) >= 0) {
+	/* FIXME: support non-local saving */
+	local_path = get_file_path_from_uri (file_uri);
+	if ((local_path != NULL) && gp_file_save (file, local_path) >= 0) {
 		if (data->delete_from_camera) 
 			data->delete_list = g_list_prepend (data->delete_list, g_strdup (camera_path));
 		if (data->adjust_orientation) {
@@ -1231,7 +1245,7 @@ save_image (DialogData *data,
 	}
 
 	g_free (camera_folder);	
-	g_free (local_path);
+	g_free (file_uri);
 	gp_file_unref (file);
 }
 
@@ -1289,7 +1303,8 @@ delete_images__done (AsyncOperationData *aodata,
 
         if (ImportPhotos) {
                 ImportPhotos = FALSE;
-                gtk_widget_show (GTK_WIDGET (data->browser));
+		if (data->browser != NULL)
+			gtk_widget_show (GTK_WIDGET (data->browser));
         }
 
         gtk_widget_destroy (data->dialog);
@@ -1496,7 +1511,7 @@ ok_clicked_cb (GtkButton  *button,
 	if (sel_list != NULL) {
 		for (scan = sel_list; scan; scan = scan->next) {
 			FileData   *fdata = scan->data;
-			const char *filename = fdata->path;
+			const char *filename = file_data_local_path (fdata);
 			file_list = g_list_prepend (file_list, g_strdup (filename));
 		}
 		if (file_list != NULL)
@@ -1641,7 +1656,7 @@ import_delete_cb (GtkButton  *button,
 	if (sel_list != NULL) {
 		for (scan = sel_list; scan; scan = scan->next) {
 			FileData   *fdata = scan->data;
-			const char *filename = fdata->path;
+			const char *filename = file_data_local_path (fdata);
 			delete_list = g_list_prepend (delete_list, g_strdup (filename));
 		}
 		if (delete_list != NULL)
@@ -1914,7 +1929,8 @@ dlg_photo_importer (GthBrowser *browser)
 
 	/* run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (browser));
+	if (browser != NULL)
+		gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (browser));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show (data->dialog);
 
