@@ -20,6 +20,7 @@
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 
 #include <glib/gi18n.h>
@@ -37,6 +38,10 @@
 #include "main.h"
 #include "pixbuf-utils.h"
 #include "dlg-save-image.h"
+#include "comments.h"
+#ifdef HAVE_LIBEXIF
+#include "gth-exif-utils.h"
+#endif /* HAVE_LIBEXIF */
 
 #define CONVERT_GLADE_FILE "gthumb_convert.glade"
 #define PROGRESS_GLADE_FILE "gthumb_tools.glade"
@@ -340,10 +345,10 @@ load_next_image (GthBatchOp *bop)
 static void
 notify_termination (GthBatchOp *bop)
 {
-	if (PD(bop)->saved_list != NULL)
-		all_windows_notify_files_created (PD(bop)->saved_list);
 	if (PD(bop)->deleted_list != NULL)
 		all_windows_notify_files_deleted (PD(bop)->deleted_list);
+	if (PD(bop)->saved_list != NULL)
+		all_windows_notify_files_created (PD(bop)->saved_list);
 	all_windows_add_monitor ();
 
 	g_signal_emit (G_OBJECT (bop),
@@ -356,11 +361,12 @@ notify_termination (GthBatchOp *bop)
 static void
 load_current_image (GthBatchOp *bop)
 {
-	FileData  *fd;
-	char      *folder;
-	char      *name_no_ext;
-	char      *utf8_name;
-	char      *message;
+	FileData   *fd;
+	char       *folder;
+	char       *name_no_ext;
+	char       *utf8_name;
+	char       *message;
+	const char *file_mime_type;
 
 	if (PD(bop)->stop_operation || (PD(bop)->current_image == NULL)) {
 		notify_termination (bop);
@@ -381,7 +387,12 @@ load_current_image (GthBatchOp *bop)
 	else
 		folder = g_strdup (PD(bop)->destination);
 	name_no_ext = remove_extension_from_path (file_name_from_path (fd->path));
-	PD(bop)->new_path = g_strconcat (folder, "/", name_no_ext, ".", PD(bop)->image_type, NULL);
+
+	file_mime_type = get_file_mime_type (fd->path, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE)); 
+	if (strcmp_null_tollerant (file_mime_type, get_mime_type_from_ext (PD(bop)->image_type)) == 0)
+		PD(bop)->new_path = g_strconcat (folder, "/", file_name_from_path (fd->path), NULL); 
+	else
+		PD(bop)->new_path = g_strconcat (folder, "/", name_no_ext, ".", PD(bop)->image_type, NULL);
 
 	g_free (folder);
 	g_free (name_no_ext);
@@ -430,7 +441,8 @@ pixbuf_op_done_cb (GthPixbufOp *pixop,
 		   gboolean     completed,
 		   GthBatchOp  *bop)
 {
-	GError *error = NULL;
+	GError   *error = NULL;
+	FileData *fd = PD(bop)->current_image->data;
 
 	if (!completed) {
 		notify_termination (bop);
@@ -443,13 +455,16 @@ pixbuf_op_done_cb (GthPixbufOp *pixop,
 			       PD(bop)->keys, 
 			       PD(bop)->values,
 			       &error)) {
-		FileData *fd = PD(bop)->current_image->data;
 		PD(bop)->saved_list = g_list_prepend (PD(bop)->saved_list, g_strdup (PD(bop)->new_path));
-		if (PD(bop)->remove_original 
-		    && (strcmp (fd->path, PD(bop)->new_path) != 0)) {
-			file_unlink (fd->path);
-			PD(bop)->deleted_list = g_list_prepend (PD(bop)->deleted_list, g_strdup (fd->path));
+
+		if (! same_uri (fd->path, PD(bop)->new_path)) {
+			comment_copy (fd->path, PD(bop)->new_path);
+			if (PD(bop)->remove_original) {
+				file_unlink (fd->path);
+				PD(bop)->deleted_list = g_list_prepend (PD(bop)->deleted_list, g_strdup (fd->path));
+			}
 		}
+
 	} else 
 		_gtk_error_dialog_from_gerror_run (PD(bop)->parent, &error);
 
