@@ -32,6 +32,7 @@
 #include <libexif/exif-content.h>
 #include <libexif/exif-entry.h>
 #include <libexif/exif-utils.h>
+#include "jpegutils/jpeg-data.h"
 
 
 typedef enum { /*< skip >*/
@@ -49,18 +50,17 @@ typedef enum { /*< skip >*/
 
 char *      get_exif_tag            (const char *filename,
 				     ExifTag     etag);
-
 ExifShort   get_exif_tag_short      (const char *filename,
 				     ExifTag     etag);
-
 time_t      get_exif_time           (const char *filename);
-
 char *      get_exif_aperture_value (const char *filename);
-
-gboolean    have_exif_data          (const char *filename);
-
+gboolean    have_exif_time          (const char *filename);
 const char *get_exif_entry_value    (ExifEntry  *entry);
-
+ExifData *  load_exif_data          (const char *filename);
+void        save_exif_data          (const char *filename,
+				     ExifData   *edata);
+void        copy_exif_data          (const char *src,
+				     const char *dest);
 
 #endif /* HAVE_LIBEXIF */
 
